/*
  ISC License

  Copyright (c) 2019, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "func.hpp"


struct Funcs
{
  Func::Access      access;
  Func::Chmod       chmod;
  Func::Chown       chown;
  Func::Create      create;
  Func::GetAttr     getattr;
  Func::GetXAttr    getxattr;
  Func::Link        link;
  Func::ListXAttr   listxattr;
  Func::Mkdir       mkdir;
  Func::Mknod       mknod;
  Func::Open        open;
  Func::Readlink    readlink;
  Func::RemoveXAttr removexattr;
  Func::Rename      rename;
  Func::Rmdir       rmdir;
  Func::SetXAttr    setxattr;
  Func::Symlink     symlink;
  Func::Truncate    truncate;
  Func::Unlink      unlink;
  Func::Utimens     utimens;
};
